ardt.preprocessors.FixedDuration
================================

.. automodule:: ardt.preprocessors.FixedDuration

   
   .. rubric:: Classes

   .. autosummary::
   
      FixedDurationPreprocessor
   